SyncUseCase<T, Params> class abstract interface

Represents a synchronous use case.

Takes Params and returns either a Failure or a valid result of type T.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(Params params) → Either<Failure, T>
Runs the use case logic synchronously.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited