sky_architecture library
Core architectural contracts, use cases, domain patterns, and exceptions.
Classes
- EmailAddress
- Represents a validated email address in the domain layer.
- Name
- Represents a validated user name in the domain layer.
- NoParams
- Represents empty parameters for use cases that do not require input.
- Password
- Represents a validated password in the domain layer.
- PhoneNumber
- Represents a validated phone number in the domain layer.
-
StreamUseCase<
T, Params> - Represents a streaming use case.
-
SyncUseCase<
T, Params> - Represents a synchronous use case.
-
UseCase<
T, Params> - Represents an asynchronous use case.
-
ValueObject<
T> - Represents a Domain-Driven Design Value Object.
Extensions
-
EitherFutureX
on Future<
Either< L, R> > -
Extensions on a Future that resolves to an
Either. - ExceptionMapper on Object
- Extension providing mapping from any Object to a domain Failure.
Exceptions / Errors
- BaseException
- A base class for data layer exceptions.
- CacheException
- Exception thrown when a local cache operation fails.
- CacheFailure
- Represents a failure resulting from a cache or local storage operation.
- Failure
- Represents a domain-level failure or error.
- NetworkException
- Exception thrown when a network communication error occurs.
- NetworkFailure
- Represents a failure resulting from network communication issues.
- ServerException
- Exception thrown when a server-side error occurs.
- ServerFailure
- Represents a failure resulting from a server-side error.
- UnknownException
- Exception thrown when an unknown or unclassified error occurs.
- UnknownFailure
- Represents a failure from an unknown or unhandled source.
- ValidationException
- Exception thrown when validation fails on data.
- ValidationFailure
- Represents a failure due to invalid inputs or failed validation checks.